// Libraries
import React from 'react'

// Components
import { PaymentSummary } from '../../../src/components/checkout/payment-summary'

// Objects
import { Flash } from '../../../src/objects/flash'

test("doesn't add errors class when there are no errors", () => {
  const wrapper = shallow(<PaymentSummary headerTitle={'Paymment'} billingAddress={{}} />)

  expect(wrapper.find('div')).not.toMatchSelector('.o-form__error')
})

test('add errors class when errors are present', () => {
  const wrapper = shallow(<PaymentSummary headerTitle={'Paymment'} billingAddress={{}} withErrors={true} />)

  expect(wrapper.find('div')).toMatchSelector('.o-form__error')
})

test('renders error messages', () => {
  // Arrange
  const errorMessage = 'Something went wrong'
  const headerTitle = 'Payment Details'

  // Act
  const wrapper = shallow(
    <PaymentSummary
      headerTitle={headerTitle}
      billingAddress={{}}
      errorMessage={errorMessage}
    />
  )

  // Assert
  expect(wrapper).toMatchSnapshot()
  expect(wrapper.find(Flash).length).toEqual(1)
})


test('renders address correctly', () => {
  // Arrange
  const billingAddress = {
    address_line_1: '112 some street',
    address_line_2: 'Somewhere',
    city: 'Leeds',
    first_name: 'John',
    last_name: 'Smith',
    postcode: 'LS18DS',
    meta_attributes: {
      company_name: {
        value: 'Company',
        data_type: 'text'
      }
    }
  }
  const headerTitle = 'Payment Details'

  // Act
  const wrapper = shallow(
    <PaymentSummary
      headerTitle={headerTitle}
      billingAddress={billingAddress}
    />
  )

  // Assert
  expect(wrapper).toMatchSnapshot()
  expect(wrapper).toIncludeText(billingAddress.address_line_1)
  expect(wrapper).toIncludeText(billingAddress.address_line_2)
  expect(wrapper).toIncludeText(billingAddress.city)
  expect(wrapper).toIncludeText(billingAddress.first_name)
  expect(wrapper).toIncludeText(billingAddress.last_name)
  expect(wrapper).toIncludeText(billingAddress.meta_attributes.company_name.value)
})