// Libraries
import React, { Fragment, PureComponent } from 'react'
import PropTypes from 'prop-types'

// Lib
import { AddressFormHeader } from '../checkout/address-form-header'

export class AddressFormSummary extends PureComponent {

  /**
   * Renders the address company name if present
   * @param  {String} companyName
   * @return {String} - HTML markup for the component
   */
  renderCompanyName (companyName) {
    if (companyName) {
      return <span>{ companyName }, </span>
    }
  }

  /**
   * Renders the address line 2 if present
   * @param  {String} addressLine2
   * @return {String} - HTML markup for the component
   */
  renderAddressLine2 (addressLine2) {
    if (addressLine2) {
      return <span>, { addressLine2 }</span>
    }
  }

  renderAddress () {
    const {
      addressLine1,
      addressLine2,
      city,
      companyName,
      firstName,
      lastName,
      postcode
    } = this.props

    return (
      <div className='o-form__wrapper--collapsed c-address-form__summary'>
        <p className='u-bold'>{ firstName } { lastName } </p>
        <span>{ this.renderCompanyName(companyName) } { addressLine1 } { this.renderAddressLine2(addressLine2) }, { city }, { postcode }</span>
      </div>
    )
  }

  render () {
    const {
      headerTitle,
      onClick,
      showEditButton
    } = this.props

    return (
      <Fragment>
        <AddressFormHeader
          collapsed
          onClick={onClick}
          showEditButton={showEditButton}
          title={headerTitle}
        />
        { this.renderAddress() }
      </Fragment>
    )
  }
}

AddressFormSummary.propTypes = {
  addressLine1: PropTypes.string,
  addressLine2: PropTypes.string,
  city: PropTypes.string,
  companyName: PropTypes.string,
  firstName: PropTypes.string,
  headerTitle: PropTypes.string.isRequired,
  lastName: PropTypes.string,
  onClick: PropTypes.func,
  postcode: PropTypes.string,
  showEditButton: PropTypes.bool
}
