// Libraries
import React, { Fragment, PureComponent } from 'react'
import PropTypes from 'prop-types'
import classNames from 'classnames'

// Lib
import { Flash } from '../../objects/flash'
import PaymentHeader from '../checkout/payment-header'

export class PaymentSummary extends PureComponent {
  /**
   * Renders the address company name if present
   * @param  {Object} address
   * @return {String} - HTML markup for the component
   */
  renderCompanyName (address) {
    const metaAttributes = address.meta_attributes
    if (metaAttributes && metaAttributes.company_name) {
      return <span>{ metaAttributes.company_name.value }, </span>
    }
  }

  /**
   * Renders the address line 2 if present
   * @param  {Object} address
   * @return {String} - HTML markup for the component
   */
  renderAddressLine2 (address) {
    if ( address.address_line_2 ) {
      return <span>, { address.address_line_2 }</span>
    }
  }

  renderBillingAddress () {
    const { billingAddress } = this.props

    return (
      <Fragment>
        <span className='u-bold'>{ billingAddress.first_name } { billingAddress.last_name } </span>
        <span>{ this.renderCompanyName(billingAddress) } { billingAddress.address_line_1 } { this.renderAddressLine2(billingAddress) }, { billingAddress.city }, { billingAddress.postcode }</span>
      </Fragment>
    )
  }

  render () {
    const { errorMessage, headerTitle, onClick, showEditButton, withErrors } = this.props
    return (
      <>
        <PaymentHeader
          title={headerTitle}
          collapsed
          onClick={onClick}
          showEditButton={showEditButton}
        />
        <div className={classNames('c-payment__summary', 'o-form__wrapper--collapsed', { 'o-form__error': withErrors })}>
          { errorMessage && <Flash text={errorMessage} modifier={'error'}/> }
          <p>
            <span className='u-bold'>Billing Address: </span>
            { this.renderBillingAddress() }
          </p>
        </div>
      </>
    )
  }
}

PaymentSummary.propTypes = {
  billingAddress: PropTypes.object,
  errorMessage: PropTypes.string,
  headerTitle: PropTypes.string.isRequired,
  onClick: PropTypes.func,
  showEditButton: PropTypes.bool,
  withErrors: PropTypes.bool
}
