// Libraries
import React, { Component } from 'react'
import classNames from 'classnames'
import { connectSearchBox } from 'react-instantsearch-dom'
import debounce from 'lodash/debounce'

const SEARCH_DEBOUNCE_MS = 400

class SearchBar extends Component {
  constructor (props) {
    super(props)
    this.handleChange = this.handleChange.bind(this)
    this.state = { searchTerm: props.searchTerm }
  }

  handleChange (event) {
    event.persist()
    const { onSetSearchTerm } = this.props
    onSetSearchTerm(event.target.value)
    this.setState({ searchTerm: event.target.value })
  }

  componentDidUpdate (prevProps) {
    const { refine, searchTerm } = this.props
    if (prevProps.searchTerm !== searchTerm) {
      debounce(() => refine(searchTerm), SEARCH_DEBOUNCE_MS)()
      this.setState({ searchTerm: searchTerm })
    }
  }

  render () {
    const { filterCategory, onCategoryFilterCleared, placeHolder } = this.props
    const { searchTerm } = this.state
    
    // unicode nbsp so we can replace spaces in category names if they appear
    const nbsp = String.fromCharCode(160)

    return (
      <form
        action='/search'
        method='get'
        className='c-searchbox__form'
        noValidate
        onSubmit={e => e.preventDefault()}
        role='search'
      >
        { filterCategory && <div className='c-searchbox__filter'>
          <span className='c-searchbox__category-name'>{ filterCategory.split(' ').join(nbsp) }</span>
          <div
            className='c-searchbox__clear-filter'
            onClick={onCategoryFilterCleared}
          />
        </div> }
        <input
          className={classNames('c-searchbox__input', {
            'c-searchbox__input--with-filter': filterCategory
          })}
          name='query'
          onChange={this.handleChange}
          placeholder={placeHolder || 'Search here…'}
          type='search'
          value={searchTerm}
        />
        <button
          className='c-searchbox__submit'
          title='Submit your search query.'
          type='submit'
        />
      </form>
    )
  }
}

export default connectSearchBox(SearchBar)
